package App::FatPackUtils;

our $DATE = '2015-04-16'; # DATE
our $VERSION = '0.01'; # VERSION

use 5.010001;

1;
# ABSTRACT: Collection of CLI utilities related to App::FatPacker

__END__

=pod

=encoding UTF-8

=head1 NAME

App::FatPackUtils - Collection of CLI utilities related to App::FatPacker

=head1 VERSION

This document describes version 0.01 of App::FatPackUtils (from Perl distribution App-FatPackUtils), released on 2015-04-16.

=head1 DESCRIPTION

This distribution provides the following command-line utilities related to
L<App::FatPacker>:

=over

=item * L<fatpack-info>

=back

=head1 SEE ALSO

L<App::FatPacker>, L<App::fatten>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-FatPackUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-FatPackUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FatPackUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
